@@ -5,19 +5,21 @@
 #' output from methods \code{head} and \code{tail}.
 #'
 #' @param x an R object.
-#' @param n a single integer. If positive, half the size for the resulting
-#'   object: number of elements for a vector (including lists), rows for a
-#'   matrix or data frame or lines for a function, to be retained from each
-#'   end. If negative, all but the n last and n first number of elements of x.
+#' @param n integer. If positive, \code{n} rows or members in the
+#'   returned object are copied from each of "head" and "tail" of \code{x}.
+#'   If negative, all except \code{n} elements of \code{x} from each of "head"
+#'   and "tail" are returned.
 #' @param ... arguments to be passed to or from other methods.
 #'
-#' @return An object (usually) like x but generally smaller. For ftable objects
-#'  \code{x}, a transformed \code{format(x)}.
+#' @return An object (usually) like \code{x} but smaller, except when
+#'  \code{n = 0}. For \code{ftable} objects \code{x}, a transformed
+#'  \code{format(x)}.
 #'
-#' @details The value returned by head_tail() is equivalent to row binding the
-#'  the values returned by head() and tail(), although not implemented in this
-#'  way. The same specializations as defined in package 'utils' for head() and
-#'  tail() have been implemented.
+#' @details The value returned by \code{head_tail()} is equivalent to row
+#'   binding the the values returned by \code{head()} and \code{tail()},
+#'   although not implemented in this way. The same specializations as defined
+#'   in package 'utils' for \code{head()} and \code{tail()} have been
+#'   implemented.
 #'
 #' @seealso \code{\link[utils]{head}}, and compare the examples and the values
 #'  returned to the examples below.
@@ -41,7 +43,7 @@
 #'
 #' head_tail(stats::ftable(Titanic))
 #'
-head_tail <- function(x, n, ...) UseMethod("head_tail")
+head_tail <- function(x, n = 3L, ...) UseMethod("head_tail")
 
 #' @describeIn head_tail Default method
 #'
